==> enc-hosts-0.3.2.tar.gz: enc-hosts-0.3.2/README.md <==
# enc-hosts - query hosts from ENC

Queries ENC (for now, Foreman) for host-type assets and applies templates to
generate host files, etc.

## Configuration

A configuration file must be present containing, at the least, a URL to the
ENC server and credentials to authenticate against it.

See `enc-hosts.conf.example` for configuration options, descriptions and
defaults.

### Foreman configuration

The user provided for access to Foreman should be:

* A service account, not a real user
* Must have "Location" and "Organization" set to "Default Location" and
  "Default Organization" respectively
* Must have the "View Hosts" and "Host Detail Viewer" roles assigned

Users can be created and configured in Foreman by an administrator.

## Caching

To avoid undue load on the ENC server, especially during testing, a caching
mechanism is available.  To activate, create the desired directory and specify
`cache_dir` in the configuration file.  If this option is present and the
directory exists, results of all searches will be saved in this location.

Cached results are only used if `--use-cache` is specified on invocation.

## Invocation

```
usage: enc-hosts [-h] [-c CONFIG] [--use-cache] [--search SEARCH]
  [--suffix SUFFIX] [--facts] TEMPLATE [TEMPLATE ...]

Pull host information from ENC (enterprise node classifier) and run through
given template.

positional arguments:
  TEMPLATE              Template(s) to render

optional arguments:
  -h, --help            show this help message and exit
  -c CONFIG, --config CONFIG
                        Configuration file
  --use-cache           Use cached results if available
  --search SEARCH       Host search string
  --suffix SUFFIX       Suffix to apply to rendered templates
  --facts               Also pull facts for each host (CAUTION: very resource
                        intensive)
```

## Search examples

* single host (probably won't use this much, but good for testing)
    ```
    $ enc-hosts --search=name=vtds01.ldap.computecanada.ca template1
    ```
* hosts owned by a specific group
    ```
    $ enc-hosts --search=usergroup=IONT template1
    ```
* oh dang, hosts matching one of two patterns!
    ```
    $ enc-hosts --search='name~*.ldap.computecanada.ca||name~*.iont.computecanada.ca' template1
    ```

## Templates

Output is rendered using [Jinja2
templates](https://jinja.palletsprojects.com/en/2.11.x/templates/).
Examples may be found in the `templates/` directory.  Templates are expected
to end in a `.jinja` extension but should be specified without it.

Templates may rely on having access to a `hosts` dictionary describing each
host record as retrieved from the ENC, keyed on the hostname.

Two templates are provided as examples:

* `templates/yaml.jinja` is a fairly trivial example that renders the
  information as YAML.
* `templates/netgroup.jinja` is more complex and is specific to the IONT.  It
  demonstrates how the template may implement its own logic to transform the
  input data into arbitrary output formats.

## Rendered output

When templates are applied to the data the rendered output is stored in a
file in the current working directory whose name is composed of the base
template name appended with a suffix optionally provided at invocation or
`.out` otherwise.

==> enc-hosts-0.4.4.tar.gz: enc-hosts-0.4.4/README.md <==
# enc-hosts - query hosts from ENC

Queries ENC (for now, Foreman) for host-type assets and applies templates to
generate host files, etc.

## Configuration

A configuration file must be present containing, at the least, a URL to the
ENC server and credentials to authenticate against it.

See `enc-hosts.conf.example` for configuration options, descriptions and
defaults.

### Foreman configuration

The user provided for access to Foreman should be:

* A service account, not a real user
* Must have "Location" and "Organization" set to "Default Location" and
  "Default Organization" respectively
* Must have the "View Hosts" and "Host Detail Viewer" roles assigned

Users can be created and configured in Foreman by an administrator.

## Caching

To avoid undue load on the ENC server, especially during testing, a caching
mechanism is available.  To activate, create the desired directory and specify
`cache_dir` in the configuration file.  If this option is present and the
directory exists, results of all searches will be saved in this location.

Cached results are only used if `--use-cache` is specified on invocation.

## Pagination

Results can be retrieved using pagination to split results into batches and
show progress of longer queries, or without pagination so that results are
received in one batch.

Pagination is useful to show progress in retrieval when working interactively
to develop queries and templates.  Turning it off saves significant time on
longer queries (limited testing showed 4m20s for paginated results vs 3m20s
for non-paginated when querying all hosts).  The default is to paginate and
the recommendation is to turn pagination off when using this command in a
script or cron job.

## Invocation

```
usage: enc-hosts [-h] [-c CONFIG] [--use-cache]
                 [--pagination RESULTS | --no-pagination] [--search SEARCH]
                 [--suffix SUFFIX] [--facts]
                 TEMPLATE [TEMPLATE ...]

Pull host information from ENC (enterprise node classifier) and run through
given template.

positional arguments:
  TEMPLATE              Template(s) to render

optional arguments:
  -h, --help            show this help message and exit
  -c CONFIG, --config CONFIG
                        Configuration file
  --use-cache           Use cached results if available
  --pagination RESULTS  Paginate results with RESULTS per page
  --no-pagination       Do not paginate
  --search SEARCH       Host search string
  --suffix SUFFIX       Suffix to apply to rendered templates
  --facts               Also pull facts for each host (CAUTION: very resource
                        intensive)
```

## Search examples

* single host (probably won't use this much, but good for testing)
    ```
    $ enc-hosts --search=name=vtds01.ldap.computecanada.ca template1
    ```
* hosts owned by a specific group
    ```
    $ enc-hosts --search=usergroup=IONT template1
    ```
* oh dang, hosts matching one of two patterns!
    ```
    $ enc-hosts --search='name~*.ldap.computecanada.ca||name~*.iont.computecanada.ca' template1
    ```

## Templates

Output is rendered using [Jinja2
templates](https://jinja.palletsprojects.com/en/2.11.x/templates/).
Examples may be found in the `templates/` directory.  Templates are expected
to end in a `.jinja` extension but should be specified without it.

Templates may rely on having access to a `hosts` dictionary describing each
host record as retrieved from the ENC, keyed on the hostname.

Two templates are provided as examples:

* `templates/yaml.jinja` is a fairly trivial example that renders the
  information as YAML.
* `templates/netgroup.jinja` is more complex and is specific to the IONT.  It
  demonstrates how the template may implement its own logic to transform the
  input data into arbitrary output formats.

## Rendered output

When templates are applied to the data the rendered output is stored in a
file in the current working directory whose name is composed of the base
template name appended with a suffix optionally provided at invocation or
`.out` otherwise.
